#!/bin/bash

#$1 - file-name

set -e

if [ $# -ne 1 ]; then
  echo "Usage: $0 <file-name>"
  exit 1
fi

FILE_NAME=$1.tar.gz
DIR=saved_files

#clean up before we start
cd /tmp;
/bin/rm -rf $DIR *.tar.gz 2> /dev/null
cd - > /dev/null

mkdir -p /tmp/$DIR
mkdir -p /tmp/$DIR/cores

function copy_files {
  TMA_DIR=$1
  TOSA_DIR=tosa
  mkdir -p /tmp/$DIR/$TMA_DIR;

  #copy conf files
  /bin/cp -r /opt/$TMA_DIR/tma.conf /tmp/$DIR/$TMA_DIR 2> /dev/null || :;
  /bin/cp -r /opt/$TMA_DIR/tma_conf.json /tmp/$DIR/$TMA_DIR 2> /dev/null || :;

  #copy all logs
  /bin/cp -r /var/log/$TMA_DIR/*.log* /tmp/$DIR/$TMA_DIR 2> /dev/null || :;
  /bin/cp -r /var/log/$TOSA_DIR/*.log* /tmp/$DIR/$TMA_DIR 2> /dev/null || :;

  #copy system logs
  /bin/cp /var/log/{dmesg*,messages*,secure*,yum.log*,pluto*} /tmp/$DIR/$TMA_DIR 2> /dev/null || :;
}

#loop through all TMA folders in /opt/
echo "$TMA_DIR";
for f in /opt/*;
do
  if [[ ${f} == /opt/tma* ]] && [[ -d "$f" && ! -L "$f" ]];
  then
      copy_files $(basename $f);
  fi
done

#copy core dump files
/bin/cp  /var/log/core.* /tmp/$DIR/cores 2> /dev/null || :;

#create tar.gz file
cd /tmp;
/bin/tar czf $FILE_NAME $DIR/  2> /dev/null

#clean up
/bin/rm -rf $DIR 2> /dev/null
